*                                                                              .
*            SPSS Program to Score the TIMSS 2007 4th Grade Items              .
*                           TIMSS 2007 User Guide                              .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM).
       RECODE !I (10 THRU 19 = 1      )
                 (20 THRU 29 = 2      )
                 (30 THRU 39 = 3      )
                 (70 THRU 79 = 0      )
                 (!NR        = 0      ) /* Not Reached      */
                 (!NA        = SYSMIS ) /* Not Administered */
                 (!OM        = 0      ) /* Omitted          */
                 (!OTHER     = 0      ) /* Other Missing    */
                 (ELSE       = 0      ).
    !DOEND .
 !IFEND .

!ENDDEFINE.

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'asa',!CTY,'m4.sav')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = M031045  M041094  M031050  M041164  M041336  M031085  M031172
                 M041329  M041184  M031029  M031064  M041125  M041135  M041264
                 M031159  M041175  M041199  M031210  M041046  M041169  M031002
                 M041034  S031264  S041042  S041079  S031078  S041047  S041087
                 S031239  S041014  S031075  S041008  S031410  S041178  S041305
                 S031077  S041070  S041171  S031291  S031068  S041010  S041017
                 S041124  S041303  /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = M041039  M041006  M031255  M041052  M031242C M031219  M041335
                 M031332  M031254  M031006  M031135  M041068  M041268  M031187
                 M031251  M041011  M031252  M031004  M041280  M041048  M041262
                 M031071  M041004  M041132  S041007  S041164  S041051  S031229
                 S031401  S041165  S041054  S031255  S041117  S041163  S041208
                 S031317  S031427  S041002  S041191  S031361  S031298  S041311
                 S041069  S041100  S031254  S031273  S031281  S031311  S041052
                 S031356  S031418  /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = M031335  M041330  M041173  M031334  M041069  M041152  M041131
                 M031303  M041010  M041158  M041155  M031098  M041289  M041065A
                 M041151  M031109  M041107  M041041  M031043  M031088  M041333
                 M041177  M041302A M041153  S031193  S031347  S041196  S041089
                 S041156A S031319  S041215  S031205  S041120  S041049  S031431
                 S031283  S031422  S031387  S041223  S031340  S031084  S031275
                 S041180  S041050  S041209  S041102  S041119  /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = M041014  M041281  M041186  M031245  M031173  M041098  M031038
                 M031276  M031351  M041096  M031223  M031294  M031218  M041320
                 M041265  M031317  M031093  M031155  M041298  M041007  M041271
                 M031083  M031185  M041023  M041254  M041191  S041160  S041217
                 S041308  S041205  S031426  S041009  S041026  S041134C S031236
                 S031001  S041187  S041092  S031266  S031389  S041080  S031230
                 S031371  S031376  S041034  S041105  S041193  /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = M031286  M031106  M031282  M031227  M031068  M031299  M031301
                 M031271  M031134  M041278  M041250  M041300A M041300B M041300C
                 M041300D M041274  M041203  M031235  M031285  M031258  M031041
                 M031350A M031350B M031350C M031274  M031240  M041056  M041076
                 M041146  M041258A M041258B M041275  M031309  M031242A M031242B
                 M031247  M041064  M041003  M041104  M041299  M041143  M041328
                 M041284  M031030  M031330  M041291  M041065B M041257  M041182
                 M041200  M031128  M031016  M031183  M031297  M031133  M041122
                 M041115A M041115B M041160A M041160B M041327  M041148  M031009
                 M031316  M031079B M031079C M031325  M041059  M041267  M041276A
                 M041276B M031346A M031346B M031346C M031379  M031380  M031313
                 M041087  M041124  M041302B M041302C M041165  M041174  S031446A
                 S031446B S031446C S031445A S031445B S031447  S031346  S031081
                 S041018  S041073  S041211  S041156B S031270  S031026  S031414A
                 S031414B S031009  S031384A S031384B S041023  S041001  S041029
                 S041179  S041216  S041061  S041202  S031240A S031240B S031240D
                 S031235A S031235B S031399A S031399B S031393  S031278  S041003
                 S041224  S041039  S041181  S041174  S041060  S041201A S041201B
                 S031190  S031047  S031396A S031396B S031396D S041177  S041183
                 S041195  S041134A S041134B S041107  S041113  S031391A S031391B
                 S031391D S031421  S031076  S041182  S041013A S041013B S041067
                 S041048  S041110  S031233  S031204  S031299  S031088A S031088B
                 S031088D S041027  S041043  S041006  S041301  S041033  S041077
                 S041081  S031325  S031197A S031197B S031197D S031044  S031390A
                 S031390B S031390D S041186  S041037  S041149A S041149B S041149D
                 S041032  S041068  /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'asc',!CTY,'m4.sav')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = dza arm aus aut twn col cze dnk slv eng
               geo deu hkg hun irn ita jpn kaz kwt lva
               ltu mng mar nld nzl nor qat rus sco sgp
               svk svn swe tun ukr usa yem adu cab cbc
               cot cqu uma umn .
